Package: CIMICE
Type: Package
Title: CIMICE-R: (Markov) Chain Method to Inferr Cancer Evolution
Version: 1.20.0
Authors@R: 
    c(
        person("Nicolò", "Rossi",
            role=c("aut", "cre"), email="olocin.issor@gmail.com",
            comment = c("Lab. of Computational Biology and Bioinformatics, Department of Mathematics, Computer Science and Physics, University of Udine",ORCID = "0000-0002-6353-7396"))
    )
Description: 
    CIMICE is a tool in the field of tumor phylogenetics and
    its goal is to build a Markov Chain (called Cancer Progression Markov Chain,
    CPMC) in order to model tumor subtypes evolution.
    The input of CIMICE is a Mutational Matrix, so a boolean matrix representing
    altered genes in a collection of samples. These samples are assumed to be
    obtained with single-cell DNA analysis techniques and the tool is 
    specifically written to use the peculiarities of this data for the CMPC
    construction.
License: Artistic-2.0
Encoding: UTF-8
Imports: dplyr, ggplot2, glue, tidyr, igraph, networkD3, visNetwork,
        ggcorrplot, purrr, ggraph, stats, utils, maftools, assertthat,
        tidygraph, expm, Matrix
RoxygenNote: 7.1.2
VignetteBuilder: knitr
Suggests: BiocStyle, knitr, rmarkdown, testthat, webshot
biocViews: Software, BiologicalQuestion, NetworkInference,
        ResearchField, Phylogenetics, StatisticalMethod,
        GraphAndNetwork, Technology, SingleCell
BugReports: https://github.com/redsnic/CIMICE/issues
URL: https://github.com/redsnic/CIMICE
BiocType: Software
git_url: https://git.bioconductor.org/packages/CIMICE
git_branch: RELEASE_3_23
git_last_commit: 80dd32c
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:14:39 UTC; biocbuild
Author: Nicolò Rossi [aut, cre] (Lab. of Computational Biology and
    Bioinformatics, Department of Mathematics, Computer Science and
    Physics, University of Udine, ORCID:
    <https://orcid.org/0000-0002-6353-7396>)
Maintainer: Nicolò Rossi <olocin.issor@gmail.com>
