# Generated by roxygen2: do not edit by hand

export(annotate_mutational_matrix)
export(binary_radix_sort)
export(build_subset_graph)
export(build_topology_subset)
export(chunk_reader)
export(compact_dataset)
export(computeDWNW)
export(computeUPW)
export(compute_weights_default)
export(corrplot_from_mutational_matrix)
export(corrplot_genes)
export(corrplot_samples)
export(dataset_preprocessing)
export(dataset_preprocessing_population)
export(draw_ggraph)
export(draw_networkD3)
export(draw_visNetwork)
export(example_dataset)
export(example_dataset_withFreqs)
export(finalize_generator)
export(fix_clonal_genotype)
export(format_labels)
export(gene_mutations_hist)
export(get_no_of_children)
export(graph_non_transitive_subset_topology)
export(make_dataset)
export(make_generator_stub)
export(make_labels)
export(normalizeDWNW)
export(normalizeUPW)
export(perturb_dataset)
export(plot_generator)
export(prepare_generator_edge_set_command)
export(prepare_labels)
export(quick_run)
export(read)
export(read_CAPRI)
export(read_CAPRI_string)
export(read_CAPRIpop)
export(read_CAPRIpop_string)
export(read_MAF)
export(read_matrix)
export(remove_transitive_edges)
export(sample_mutations_hist)
export(select_genes_on_mutations)
export(select_samples_on_mutations)
export(set_generator_edges)
export(simulate_generator)
export(to_dot)
export(update_df)
import(Matrix)
importFrom(assertthat,are_equal)
importFrom(assertthat,assert_that)
importFrom(dplyr,"%>%")
importFrom(dplyr,count)
importFrom(dplyr,enexprs)
importFrom(dplyr,group_by)
importFrom(dplyr,group_by_all)
importFrom(dplyr,inner_join)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_all)
importFrom(dplyr,n)
importFrom(dplyr,pull)
importFrom(dplyr,select)
importFrom(dplyr,select_if)
importFrom(dplyr,summarise)
importFrom(dplyr,ungroup)
importFrom(expm,"%^%")
importFrom(ggcorrplot,ggcorrplot)
importFrom(ggplot2,aes)
importFrom(ggplot2,arrow)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,unit)
importFrom(ggraph,geom_edge_link)
importFrom(ggraph,geom_edge_loop)
importFrom(ggraph,geom_node_label)
importFrom(ggraph,geom_node_point)
importFrom(ggraph,ggraph)
importFrom(ggraph,label_rect)
importFrom(glue,glue)
importFrom(igraph,"E<-")
importFrom(igraph,"V<-")
importFrom(igraph,E)
importFrom(igraph,V)
importFrom(igraph,as_adj)
importFrom(igraph,as_edgelist)
importFrom(igraph,as_ids)
importFrom(igraph,get.edge.ids)
importFrom(igraph,graph_from_adjacency_matrix)
importFrom(igraph,graph_from_edgelist)
importFrom(igraph,head_of)
importFrom(igraph,tail_of)
importFrom(maftools,mutCountMatrix)
importFrom(maftools,read.maf)
importFrom(networkD3,forceNetwork)
importFrom(networkD3,igraph_to_networkD3)
importFrom(purrr,imap_chr)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(purrr,map2_chr)
importFrom(purrr,map_chr)
importFrom(purrr,map_dbl)
importFrom(purrr,map_int)
importFrom(purrr,rbernoulli)
importFrom(stats,cor)
importFrom(tidygraph,"%E>%")
importFrom(tidygraph,"%N>%")
importFrom(tidygraph,activate)
importFrom(tidygraph,as_tbl_graph)
importFrom(tidygraph,bind_edges)
importFrom(tidyr,drop_na)
importFrom(utils,read.csv)
importFrom(visNetwork,toVisNetworkData)
importFrom(visNetwork,visHierarchicalLayout)
importFrom(visNetwork,visNetwork)
