% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/analysis.R
\name{dataset_preprocessing}
\alias{dataset_preprocessing}
\title{Run CIMICE preprocessing}
\usage{
dataset_preprocessing(dataset)
}
\arguments{
\item{dataset}{a mutational matrix as a (sparse) matrix}
}
\value{
a list containing the mutational matrix ("samples"),
the mutational frequencies of the genotypes ("freqs"),
the node labels ("labels") and finally the gene names ("genes")
}
\description{
executes the preprocessing steps of CIMICE
}
\details{
Preprocessing steps:

1) dataset is compacted

2) genotype frequencies are computed

3) labels are prepared
}
\examples{
require(dplyr)
example_dataset() \%>\% dataset_preprocessing

}
